#ifndef CLDAQ__CONSTANTS_H
#define CLDAQ__CONSTANTS_H

static const Tint len = 24;
Tint nevent[len] =
  {1,10,20,50,100,200,500,1000,2000,5000,10000,20000,30000,40000,50000,60000,70000,80000,90000,100000,200000,300000,400000,500000};

#endif
